==> jc-1.4.0.tar.gz: javax/swing/JToolTip__24AccessibleJToolTip.h <==
// public class javax.swing.JToolTip$AccessibleJToolTip

// class file dependencies
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class 6102783307e099ec javax_swing_JToolTip__24AccessibleJToolTip

// header file dependencies
// @dep_header javax_swing_JComponent__24AccessibleJComponent

#include "javax/swing/JComponent__24AccessibleJComponent.h"

#ifndef _JC_javax_swing_JToolTip__24AccessibleJToolTip_H_
#define _JC_javax_swing_JToolTip__24AccessibleJToolTip_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_swing_JToolTip$object;

// Typedefs
typedef struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$sub_refs	_jc_javax_swing_JToolTip__24AccessibleJToolTip$sub_refs;
typedef struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$sub_nonrefs	_jc_javax_swing_JToolTip__24AccessibleJToolTip$sub_nonrefs;
typedef struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$refs	_jc_javax_swing_JToolTip__24AccessibleJToolTip$refs;
typedef struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$nonrefs	_jc_javax_swing_JToolTip__24AccessibleJToolTip$nonrefs;
typedef struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$object	_jc_javax_swing_JToolTip__24AccessibleJToolTip$object;

typedef const struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$vmethods	_jc_javax_swing_JToolTip__24AccessibleJToolTip$vmethods;
typedef const struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$vtable	_jc_javax_swing_JToolTip__24AccessibleJToolTip$vtable;
typedef const struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$vtype	_jc_javax_swing_JToolTip__24AccessibleJToolTip$vtype;

// Constructors
extern void _jc_javax_swing_JToolTip__24AccessibleJToolTip$method$_init$dafbf8dd2569eb3e(_jc_env *, struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$object *, struct _jc_javax_swing_JToolTip$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_swing_JToolTip__24AccessibleJToolTip$method$getAccessibleDescription$8f9a14aed2691743(_jc_env *, struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$object *);
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JToolTip__24AccessibleJToolTip$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JToolTip__24AccessibleJToolTip$method_info$getAccessibleDescription$8f9a14aed2691743;
extern _jc_method _jc_javax_swing_JToolTip__24AccessibleJToolTip$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$vmethods {
	struct _jc_java_lang_String$object	*(*getAccessibleDescription$8f9a14aed2691743)(_jc_env *, struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$object *);
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$object *);
};

// Vtable
struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_JToolTip__24AccessibleJToolTip$vmethods	javax_swing_JToolTip__24AccessibleJToolTip;
};

// Vtype
struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$vtype {
	_jc_type			type;
	_jc_javax_swing_JToolTip__24AccessibleJToolTip$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$sub_refs {
	struct _jc_javax_swing_JToolTip$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$refs {
    _jc_javax_swing_JToolTip__24AccessibleJToolTip$sub_refs	javax_swing_JToolTip__24AccessibleJToolTip;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_JToolTip__24AccessibleJToolTip$sub_nonrefs	javax_swing_JToolTip__24AccessibleJToolTip;
};

// Object instance structure
struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$object {
	_jc_javax_swing_JToolTip__24AccessibleJToolTip$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JToolTip__24AccessibleJToolTip$vtype	*vtype;
	_jc_javax_swing_JToolTip__24AccessibleJToolTip$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JToolTip__24AccessibleJToolTip$vtype _jc_javax_swing_JToolTip__24AccessibleJToolTip$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JToolTip__24AccessibleJToolTip, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JToolTip__24AccessibleJToolTip$class_object;

#endif	/* _JC_javax_swing_JToolTip__24AccessibleJToolTip_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JToolTip__24AccessibleJToolTip.h <==
// public class javax.swing.JToolTip$AccessibleJToolTip

// class file dependencies
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class 6102783307e099ec javax_swing_JToolTip__24AccessibleJToolTip

// header file dependencies
// @dep_header javax_swing_JComponent__24AccessibleJComponent

#include "javax/swing/JComponent__24AccessibleJComponent.h"

#ifndef _JC_javax_swing_JToolTip__24AccessibleJToolTip_H_
#define _JC_javax_swing_JToolTip__24AccessibleJToolTip_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_swing_JToolTip$object;

// Typedefs
typedef struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$sub_refs	_jc_javax_swing_JToolTip__24AccessibleJToolTip$sub_refs;
typedef struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$sub_nonrefs	_jc_javax_swing_JToolTip__24AccessibleJToolTip$sub_nonrefs;
typedef struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$refs	_jc_javax_swing_JToolTip__24AccessibleJToolTip$refs;
typedef struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$nonrefs	_jc_javax_swing_JToolTip__24AccessibleJToolTip$nonrefs;
typedef struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$object	_jc_javax_swing_JToolTip__24AccessibleJToolTip$object;

typedef const struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$vmethods	_jc_javax_swing_JToolTip__24AccessibleJToolTip$vmethods;
typedef const struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$vtable	_jc_javax_swing_JToolTip__24AccessibleJToolTip$vtable;
typedef const struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$vtype	_jc_javax_swing_JToolTip__24AccessibleJToolTip$vtype;

// Constructors
extern void _jc_javax_swing_JToolTip__24AccessibleJToolTip$method$_init$dafbf8dd2569eb3e(_jc_env *, struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$object *, struct _jc_javax_swing_JToolTip$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_swing_JToolTip__24AccessibleJToolTip$method$getAccessibleDescription$8f9a14aed2691743(_jc_env *, struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JToolTip__24AccessibleJToolTip$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JToolTip__24AccessibleJToolTip$method_info$getAccessibleDescription$8f9a14aed2691743;
extern _jc_method _jc_javax_swing_JToolTip__24AccessibleJToolTip$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$vmethods {
	struct _jc_java_lang_String$object	*(*getAccessibleDescription$8f9a14aed2691743)(_jc_env *, struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$object *) _JC_JCNI_ATTR;
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_JToolTip__24AccessibleJToolTip$vmethods	javax_swing_JToolTip__24AccessibleJToolTip;
};

// Vtype
struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$vtype {
	_jc_type			type;
	_jc_javax_swing_JToolTip__24AccessibleJToolTip$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$sub_refs {
	struct _jc_javax_swing_JToolTip$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$refs {
    _jc_javax_swing_JToolTip__24AccessibleJToolTip$sub_refs	javax_swing_JToolTip__24AccessibleJToolTip;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_JToolTip__24AccessibleJToolTip$sub_nonrefs	javax_swing_JToolTip__24AccessibleJToolTip;
};

// Object instance structure
struct _jc_javax_swing_JToolTip__24AccessibleJToolTip$object {
	_jc_javax_swing_JToolTip__24AccessibleJToolTip$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JToolTip__24AccessibleJToolTip$vtype	*vtype;
	_jc_javax_swing_JToolTip__24AccessibleJToolTip$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JToolTip__24AccessibleJToolTip$vtype _jc_javax_swing_JToolTip__24AccessibleJToolTip$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JToolTip__24AccessibleJToolTip, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JToolTip__24AccessibleJToolTip$class_object;

#endif	/* _JC_javax_swing_JToolTip__24AccessibleJToolTip_H_ */
